@@ -1,4 +1,5 @@
 import locale
+import logging
 
 from streamlink.compat import is_py2
 
@@ -16,6 +17,8 @@ DEFAULT_LANGUAGE = "en"
 DEFAULT_COUNTRY = "US"
 DEFAULT_LANGUAGE_CODE = "{0}_{1}".format(DEFAULT_LANGUAGE, DEFAULT_COUNTRY)
 
+log = logging.getLogger(__name__)
+
 
 class Country(object):
     def __init__(self, alpha2, alpha3, numeric, name, official_name=None):
@@ -38,9 +41,9 @@ class Country(object):
             raise LookupError("Invalid country code: {0}".format(country))
 
     def __eq__(self, other):
-        return ((self.alpha2 and self.alpha2 == other.alpha2)
-                or (self.alpha3 and self.alpha3 == other.alpha3)
-                or (self.numeric and self.numeric == other.numeric))
+        return ((self.alpha2 and self.alpha2 == other.alpha2) or
+                (self.alpha3 and self.alpha3 == other.alpha3) or
+                (self.numeric and self.numeric == other.numeric))
 
     def __str__(self):
         if is_py2:
@@ -89,9 +92,9 @@ class Language(object):
             raise LookupError("Invalid language code: {0}".format(language))
 
     def __eq__(self, other):
-        return ((self.alpha2 and self.alpha2 == other.alpha2)
-                or (self.alpha3 and self.alpha3 == other.alpha3)
-                or (self.bibliographic and self.bibliographic == other.bibliographic))
+        return ((self.alpha2 and self.alpha2 == other.alpha2) or
+                (self.alpha3 and self.alpha3 == other.alpha3) or
+                (self.bibliographic and self.bibliographic == other.bibliographic))
 
     def __str__(self):
         if is_py2:
@@ -121,7 +124,7 @@ class Localization(object):
     def _parse_locale_code(self, language_code):
         parts = language_code.split("_", 1)
         if len(parts) != 2 or len(parts[0]) != 2 or len(parts[1]) != 2:
-                raise LookupError("Invalid language code: {0}".format(language_code))
+            raise LookupError("Invalid language code: {0}".format(language_code))
         return self.get_language(parts[0]), self.get_country(parts[1])
 
     @language_code.setter
@@ -147,6 +150,7 @@ class Localization(object):
                 self._language_code = DEFAULT_LANGUAGE_CODE
             else:
                 raise
+        log.debug("Language code: {0}".format(self._language_code))
 
     def equivalent(self, language=None, country=None):
         equivalent = True
